# coding: utf-8

"""
    TTS documentation

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.1

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from speechpro.cloud.speech.synthesis.rest.cloud_client.cloud_api_client import CloudApiClient


class Synthesize(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = CloudApiClient()
        self.api_client = api_client

    def language_voices_support(self, x_session_id, **kwargs):  # noqa: E501
        """Available languages  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.language_voices_support(x_session_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str x_session_id: Session identifier (required)
        :return: list[SynthesizeLanguage]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.language_voices_support_with_http_info(x_session_id, **kwargs)  # noqa: E501
        else:
            (data) = self.language_voices_support_with_http_info(x_session_id, **kwargs)  # noqa: E501
            return data

    def language_voices_support_with_http_info(self, x_session_id, **kwargs):  # noqa: E501
        """Available languages  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.language_voices_support_with_http_info(x_session_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str x_session_id: Session identifier (required)
        :return: list[SynthesizeLanguage]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_session_id']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method language_voices_support" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'x_session_id' is set
        if ('x_session_id' not in params or
                params['x_session_id'] is None):
            raise ValueError("Missing the required parameter `x_session_id` when calling `language_voices_support`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_session_id' in params:
            header_params['X-Session-ID'] = params['x_session_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=UTF-8'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/vktts/rest/v1/languages', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[SynthesizeLanguage]',  # noqa: E501
            auth_settings=auth_settings,
            async_=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def synthesize(self, x_session_id, body, **kwargs):  # noqa: E501
        """Synthesize speech from text  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.synthesize(x_session_id, body, async=True)
        >>> result = thread.get()

        :param async bool
        :param str x_session_id: Session identifier (required)
        :param SynthesizeRequest body: Synthesize param (required)
        :param str x_request_id: Request identifier
        :return: SynthesizeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.synthesize_with_http_info(x_session_id, body, **kwargs)  # noqa: E501
        else:
            (data) = self.synthesize_with_http_info(x_session_id, body, **kwargs)  # noqa: E501
            return data

    def synthesize_with_http_info(self, x_session_id, body, **kwargs):  # noqa: E501
        """Synthesize speech from text  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.synthesize_with_http_info(x_session_id, body, async=True)
        >>> result = thread.get()

        :param async bool
        :param str x_session_id: Session identifier (required)
        :param SynthesizeRequest body: Synthesize param (required)
        :param str x_request_id: Request identifier
        :return: SynthesizeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_session_id', 'body', 'x_request_id']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method synthesize" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'x_session_id' is set
        if ('x_session_id' not in params or
                params['x_session_id'] is None):
            raise ValueError("Missing the required parameter `x_session_id` when calling `synthesize`")  # noqa: E501
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `synthesize`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_session_id' in params:
            header_params['X-Session-ID'] = params['x_session_id']  # noqa: E501
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=UTF-8'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/vktts/rest/v1/synthesize', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SynthesizeResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def synthesize_sessionless(self, body, **kwargs):  # noqa: E501
        """Synthesize speech from text without session  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.synthesize_sessionless(body, async=True)
        >>> result = thread.get()

        :param async bool
        :param SynthesizeSessionlessRequest body: Synthesize param (required)
        :param str x_request_id: Request identifier
        :return: SynthesizeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.synthesize_sessionless_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.synthesize_sessionless_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def synthesize_sessionless_with_http_info(self, body, **kwargs):  # noqa: E501
        """Synthesize speech from text without session  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.synthesize_sessionless_with_http_info(body, async=True)
        >>> result = thread.get()

        :param async bool
        :param SynthesizeSessionlessRequest body: Synthesize param (required)
        :param str x_request_id: Request identifier
        :return: SynthesizeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'x_request_id']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method synthesize_sessionless" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `synthesize_sessionless`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=UTF-8'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/vktts/rest/v1/synthesize/sessionless', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SynthesizeResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def voices(self, x_session_id, language, **kwargs):  # noqa: E501
        """Available languages  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.voices(x_session_id, language, async=True)
        >>> result = thread.get()

        :param async bool
        :param str x_session_id: Session identifier (required)
        :param str language: Language name (required)
        :return: list[SynthesizeVoiceType]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.voices_with_http_info(x_session_id, language, **kwargs)  # noqa: E501
        else:
            (data) = self.voices_with_http_info(x_session_id, language, **kwargs)  # noqa: E501
            return data

    def voices_with_http_info(self, x_session_id, language, **kwargs):  # noqa: E501
        """Available languages  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.voices_with_http_info(x_session_id, language, async=True)
        >>> result = thread.get()

        :param async bool
        :param str x_session_id: Session identifier (required)
        :param str language: Language name (required)
        :return: list[SynthesizeVoiceType]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_session_id', 'language']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method voices" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'x_session_id' is set
        if ('x_session_id' not in params or
                params['x_session_id'] is None):
            raise ValueError("Missing the required parameter `x_session_id` when calling `voices`")  # noqa: E501
        # verify the required parameter 'language' is set
        if ('language' not in params or
                params['language'] is None):
            raise ValueError("Missing the required parameter `language` when calling `voices`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'language' in params:
            path_params['language'] = params['language']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_session_id' in params:
            header_params['X-Session-ID'] = params['x_session_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=UTF-8'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/vktts/rest/v1/languages/{language}/voices', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[SynthesizeVoiceType]',  # noqa: E501
            auth_settings=auth_settings,
            async_=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def web_socket_stream(self, x_session_id, body, **kwargs):  # noqa: E501
        """Get websocket connection param  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.web_socket_stream(x_session_id, body, async=True)
        >>> result = thread.get()

        :param async bool
        :param str x_session_id: Session identifier (required)
        :param WebSocketSynthesizeRequest body: Synthesize param (required)
        :param str x_request_id: Request identifier
        :return: WebSocketServerConfigurationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.web_socket_stream_with_http_info(x_session_id, body, **kwargs)  # noqa: E501
        else:
            (data) = self.web_socket_stream_with_http_info(x_session_id, body, **kwargs)  # noqa: E501
            return data

    def web_socket_stream_with_http_info(self, x_session_id, body, **kwargs):  # noqa: E501
        """Get websocket connection param  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.web_socket_stream_with_http_info(x_session_id, body, async=True)
        >>> result = thread.get()

        :param async bool
        :param str x_session_id: Session identifier (required)
        :param WebSocketSynthesizeRequest body: Synthesize param (required)
        :param str x_request_id: Request identifier
        :return: WebSocketServerConfigurationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_session_id', 'body', 'x_request_id']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method web_socket_stream" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'x_session_id' is set
        if ('x_session_id' not in params or
                params['x_session_id'] is None):
            raise ValueError("Missing the required parameter `x_session_id` when calling `web_socket_stream`")  # noqa: E501
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `web_socket_stream`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_session_id' in params:
            header_params['X-Session-ID'] = params['x_session_id']  # noqa: E501
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=UTF-8'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/vktts/rest/v1/synthesize/stream', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='WebSocketServerConfigurationResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def web_socket_stream_0(self, x_session_id, x_transaction_id, **kwargs):  # noqa: E501
        """Close transaction  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.web_socket_stream_0(x_session_id, x_transaction_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str x_session_id: Session identifier (required)
        :param str x_transaction_id: Transaction identifier (required)
        :return: CloseTransactionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.web_socket_stream_0_with_http_info(x_session_id, x_transaction_id, **kwargs)  # noqa: E501
        else:
            (data) = self.web_socket_stream_0_with_http_info(x_session_id, x_transaction_id, **kwargs)  # noqa: E501
            return data

    def web_socket_stream_0_with_http_info(self, x_session_id, x_transaction_id, **kwargs):  # noqa: E501
        """Close transaction  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.web_socket_stream_0_with_http_info(x_session_id, x_transaction_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str x_session_id: Session identifier (required)
        :param str x_transaction_id: Transaction identifier (required)
        :return: CloseTransactionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_session_id', 'x_transaction_id']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method web_socket_stream_0" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'x_session_id' is set
        if ('x_session_id' not in params or
                params['x_session_id'] is None):
            raise ValueError("Missing the required parameter `x_session_id` when calling `web_socket_stream_0`")  # noqa: E501
        # verify the required parameter 'x_transaction_id' is set
        if ('x_transaction_id' not in params or
                params['x_transaction_id'] is None):
            raise ValueError("Missing the required parameter `x_transaction_id` when calling `web_socket_stream_0`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_session_id' in params:
            header_params['X-Session-ID'] = params['x_session_id']  # noqa: E501
        if 'x_transaction_id' in params:
            header_params['X-Transaction-Id'] = params['x_transaction_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=UTF-8'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/vktts/rest/v1/synthesize/stream', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CloseTransactionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    ASR documentation

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class WordDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'word': 'str',
        'speaker': 'int',
        'score': 'str',
        'begin': 'str',
        'length': 'str',
        'stop_sign': 'str'
    }

    attribute_map = {
        'word': 'word',
        'speaker': 'speaker',
        'score': 'score',
        'begin': 'begin',
        'length': 'length',
        'stop_sign': 'stop_sign'
    }

    def __init__(self, word=None, speaker=None, score=None, begin=None, length=None, stop_sign=None):  # noqa: E501
        """WordDto - a model defined in Swagger"""  # noqa: E501

        self._word = None
        self._speaker = None
        self._score = None
        self._begin = None
        self._length = None
        self._stop_sign = None
        self.discriminator = None

        self.word = word
        if speaker is not None:
            self.speaker = speaker
        self.score = score
        if begin is not None:
            self.begin = begin
        if length is not None:
            self.length = length
        if stop_sign is not None:
            self.stop_sign = stop_sign

    @property
    def word(self):
        """Gets the word of this WordDto.  # noqa: E501

        Recognized word  # noqa: E501

        :return: The word of this WordDto.  # noqa: E501
        :rtype: str
        """
        return self._word

    @word.setter
    def word(self, word):
        """Sets the word of this WordDto.

        Recognized word  # noqa: E501

        :param word: The word of this WordDto.  # noqa: E501
        :type: str
        """
        if word is None:
            raise ValueError("Invalid value for `word`, must not be `None`")  # noqa: E501

        self._word = word

    @property
    def speaker(self):
        """Gets the speaker of this WordDto.  # noqa: E501

        Identified speaker id  # noqa: E501

        :return: The speaker of this WordDto.  # noqa: E501
        :rtype: int
        """
        return self._speaker

    @speaker.setter
    def speaker(self, speaker):
        """Sets the speaker of this WordDto.

        Identified speaker id  # noqa: E501

        :param speaker: The speaker of this WordDto.  # noqa: E501
        :type: int
        """

        self._speaker = speaker

    @property
    def score(self):
        """Gets the score of this WordDto.  # noqa: E501

        Recognition confidence (0 - 100.00)  # noqa: E501

        :return: The score of this WordDto.  # noqa: E501
        :rtype: str
        """
        return self._score

    @score.setter
    def score(self, score):
        """Sets the score of this WordDto.

        Recognition confidence (0 - 100.00)  # noqa: E501

        :param score: The score of this WordDto.  # noqa: E501
        :type: str
        """
        if score is None:
            raise ValueError("Invalid value for `score`, must not be `None`")  # noqa: E501

        self._score = score

    @property
    def begin(self):
        """Gets the begin of this WordDto.  # noqa: E501

        Time stamp on which this word was found  # noqa: E501

        :return: The begin of this WordDto.  # noqa: E501
        :rtype: str
        """
        return self._begin

    @begin.setter
    def begin(self, begin):
        """Sets the begin of this WordDto.

        Time stamp on which this word was found  # noqa: E501

        :param begin: The begin of this WordDto.  # noqa: E501
        :type: str
        """

        self._begin = begin

    @property
    def length(self):
        """Gets the length of this WordDto.  # noqa: E501

        Word duration  # noqa: E501

        :return: The length of this WordDto.  # noqa: E501
        :rtype: str
        """
        return self._length

    @length.setter
    def length(self, length):
        """Sets the length of this WordDto.

        Word duration  # noqa: E501

        :param length: The length of this WordDto.  # noqa: E501
        :type: str
        """

        self._length = length

    @property
    def stop_sign(self):
        """Gets the stop_sign of this WordDto.  # noqa: E501

        Word stop sign  # noqa: E501

        :return: The stop_sign of this WordDto.  # noqa: E501
        :rtype: str
        """
        return self._stop_sign

    @stop_sign.setter
    def stop_sign(self, stop_sign):
        """Sets the stop_sign of this WordDto.

        Word stop sign  # noqa: E501

        :param stop_sign: The stop_sign of this WordDto.  # noqa: E501
        :type: str
        """
        self._stop_sign = stop_sign

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WordDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    SessionService documentation

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.1

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from speechpro.cloud.speech.recognition.rest.cloud_client.cloud_api_client import CloudApiClient


class SessionApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = CloudApiClient()
        self.api_client = api_client

    def check(self, x_session_id, **kwargs):  # noqa: E501
        """Check session state  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.check(x_session_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str x_session_id: Session identifier (required)
        :return: AuthStatusDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.check_with_http_info(x_session_id, **kwargs)  # noqa: E501
        else:
            (data) = self.check_with_http_info(x_session_id, **kwargs)  # noqa: E501
            return data

    def check_with_http_info(self, x_session_id, **kwargs):  # noqa: E501
        """Check session state  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.check_with_http_info(x_session_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str x_session_id: Session identifier (required)
        :return: AuthStatusDto
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_session_id']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method check" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'x_session_id' is set
        if ('x_session_id' not in params or
                params['x_session_id'] is None):
            raise ValueError("Missing the required parameter `x_session_id` when calling `check`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_session_id' in params:
            header_params['X-Session-ID'] = params['x_session_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=UTF-8'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/vksession/rest/session', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AuthStatusDto',  # noqa: E501
            auth_settings=auth_settings,
            async_=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_domains(self, **kwargs):  # noqa: E501
        """Get All domains for auth without session  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_domains(async=True)
        >>> result = thread.get()

        :param async bool
        :return: DomainDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_domains_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_domains_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_domains_with_http_info(self, **kwargs):  # noqa: E501
        """Get All domains for auth without session  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_domains_with_http_info(async=True)
        >>> result = thread.get()

        :param async bool
        :return: DomainDto
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_domains" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=UTF-8'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/vksession/rest/domains', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DomainDto',  # noqa: E501
            auth_settings=auth_settings,
            async_=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_granted_privileges(self, x_session_id, body, **kwargs):  # noqa: E501
        """Get current user privileges  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_granted_privileges(x_session_id, body, async=True)
        >>> result = thread.get()

        :param async bool
        :param str x_session_id: Session identifier (required)
        :param ModuleNamesDto body: Module names (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_granted_privileges_with_http_info(x_session_id, body, **kwargs)  # noqa: E501
        else:
            (data) = self.get_granted_privileges_with_http_info(x_session_id, body, **kwargs)  # noqa: E501
            return data

    def get_granted_privileges_with_http_info(self, x_session_id, body, **kwargs):  # noqa: E501
        """Get current user privileges  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_granted_privileges_with_http_info(x_session_id, body, async=True)
        >>> result = thread.get()

        :param async bool
        :param str x_session_id: Session identifier (required)
        :param ModuleNamesDto body: Module names (required)
        :return: dict(str, object)
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_session_id', 'body']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_granted_privileges" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'x_session_id' is set
        if ('x_session_id' not in params or
                params['x_session_id'] is None):
            raise ValueError("Missing the required parameter `x_session_id` when calling `get_granted_privileges`")  # noqa: E501
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `get_granted_privileges`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_session_id' in params:
            header_params['X-Session-ID'] = params['x_session_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=UTF-8'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/vksession/rest/privileges', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, object)',  # noqa: E501
            auth_settings=auth_settings,
            async_=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def login(self, credentials, **kwargs):  # noqa: E501
        """Log in to system and obtain session identifier. Pass sessionId in &#39;X-Session-ID&#39; header in all other API requests  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.login(credentials, async=True)
        >>> result = thread.get()

        :param async bool
        :param AuthRequestDto credentials: User's credentials (required)
        :return: AuthResponseDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.login_with_http_info(credentials, **kwargs)  # noqa: E501
        else:
            (data) = self.login_with_http_info(credentials, **kwargs)  # noqa: E501
            return data

    def login_with_http_info(self, credentials, **kwargs):  # noqa: E501
        """Log in to system and obtain session identifier. Pass sessionId in &#39;X-Session-ID&#39; header in all other API requests  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.login_with_http_info(credentials, async=True)
        >>> result = thread.get()

        :param async bool
        :param AuthRequestDto credentials: User's credentials (required)
        :return: AuthResponseDto
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['credentials']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method login" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'credentials' is set
        if ('credentials' not in params or
                params['credentials'] is None):
            raise ValueError("Missing the required parameter `credentials` when calling `login`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'credentials' in params:
            body_params = params['credentials']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=UTF-8'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/vksession/rest/session', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AuthResponseDto',  # noqa: E501
            auth_settings=auth_settings,
            async_=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def logout(self, x_session_id, **kwargs):  # noqa: E501
        """Log out of system  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.logout(x_session_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str x_session_id: Session identifier (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.logout_with_http_info(x_session_id, **kwargs)  # noqa: E501
        else:
            (data) = self.logout_with_http_info(x_session_id, **kwargs)  # noqa: E501
            return data

    def logout_with_http_info(self, x_session_id, **kwargs):  # noqa: E501
        """Log out of system  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.logout_with_http_info(x_session_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str x_session_id: Session identifier (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_session_id']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method logout" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'x_session_id' is set
        if ('x_session_id' not in params or
                params['x_session_id'] is None):
            raise ValueError("Missing the required parameter `x_session_id` when calling `logout`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_session_id' in params:
            header_params['X-Session-ID'] = params['x_session_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=UTF-8'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/vksession/rest/session', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



import base64
import cloud_client
from speechpro.cloud.speech.recognition.rest.cloud_client.models.auth_request_dto import AuthRequestDto
from speechpro.cloud.speech.recognition.rest.cloud_client.api.session_api import SessionApi
from speechpro.cloud.speech.recognition.rest.cloud_client.api import PackagesApi
from speechpro.cloud.speech.recognition.rest.cloud_client.api import RecognizeApi
from speechpro.cloud.speech.recognition.rest.cloud_client.models.audio_file_dto import AudioFileDto
from speechpro.cloud.speech.recognition.rest.cloud_client.models.recognition_request_dto import RecognitionRequestDto

session_api = SessionApi()
credentials = AuthRequestDto("kozhedubov@speechpro.com", 863, "bb1e439bY#")
session_id = session_api.login(credentials).session_id
packages_api = PackagesApi()
packages_api.load(session_id, "FarField").status
in_file = open("~/documents/Projects/STC/CP/stafory/sample_1.wav", "rb")
data = in_file.read()
in_file.close()
encoded_string = base64.standard_b64encode(data)
string = str(encoded_string, 'ascii', 'ignore')
recognize_api = RecognizeApi()
audio_file = AudioFileDto(string, "audio/x-wav")
recognition_request = RecognitionRequestDto(audio_file, "FarField")
recognition_result = recognize_api.recognize(session_id, recognition_request)
print(recognition_result)



# coding: utf-8

"""
    ASR documentation

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.1

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from speechpro.cloud.speech.recognition.rest.cloud_client.models.recognition_request_dto import RecognitionRequestDto  # noqa: F401,E501
from speechpro.cloud.speech.recognition.rest.cloud_client.models.start_session_request import StartSessionRequest  # noqa: F401,E501


class SessionlessRecognitionRequestDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'user_info': 'StartSessionRequest',
        'recognition_request': 'RecognitionRequestDto'
    }

    attribute_map = {
        'user_info': 'user_info',
        'recognition_request': 'recognition_request'
    }

    def __init__(self, user_info=None, recognition_request=None):  # noqa: E501
        """SessionlessRecognitionRequestDto - a model defined in Swagger"""  # noqa: E501

        self._user_info = None
        self._recognition_request = None
        self.discriminator = None

        self.user_info = user_info
        self.recognition_request = recognition_request

    @property
    def user_info(self):
        """Gets the user_info of this SessionlessRecognitionRequestDto.  # noqa: E501

        User credentials  # noqa: E501

        :return: The user_info of this SessionlessRecognitionRequestDto.  # noqa: E501
        :rtype: StartSessionRequest
        """
        return self._user_info

    @user_info.setter
    def user_info(self, user_info):
        """Sets the user_info of this SessionlessRecognitionRequestDto.

        User credentials  # noqa: E501

        :param user_info: The user_info of this SessionlessRecognitionRequestDto.  # noqa: E501
        :type: StartSessionRequest
        """
        if user_info is None:
            raise ValueError("Invalid value for `user_info`, must not be `None`")  # noqa: E501

        self._user_info = user_info

    @property
    def recognition_request(self):
        """Gets the recognition_request of this SessionlessRecognitionRequestDto.  # noqa: E501

        User credentials  # noqa: E501

        :return: The recognition_request of this SessionlessRecognitionRequestDto.  # noqa: E501
        :rtype: RecognitionRequestDto
        """
        return self._recognition_request

    @recognition_request.setter
    def recognition_request(self, recognition_request):
        """Sets the recognition_request of this SessionlessRecognitionRequestDto.

        User credentials  # noqa: E501

        :param recognition_request: The recognition_request of this SessionlessRecognitionRequestDto.  # noqa: E501
        :type: RecognitionRequestDto
        """
        if recognition_request is None:
            raise ValueError("Invalid value for `recognition_request`, must not be `None`")  # noqa: E501

        self._recognition_request = recognition_request

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SessionlessRecognitionRequestDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from speechpro.cloud.speech.recognition.rest.cloud_client.api.packages_api import PackagesApi
from speechpro.cloud.speech.recognition.rest.cloud_client.api.recognize_api import RecognizeApi
from speechpro.cloud.speech.recognition.rest.cloud_client.api.session_api import SessionApi



import base64

from speechpro.cloud.speech.recognition.rest.cloud_client.api import RecognizeApi
from speechpro.cloud.speech.recognition.rest.cloud_client.models import AudioFileDto, RecognitionRequestDto, AdvancedRecognitionRequestDto

from speechpro.cloud.speech.recognition import enums


CONFIG_MODEL_KEY = 'model'


class ShortAudioRecognitionClient():

    model_mapping = {
        (enums.Language.RU, enums.Model.GENERAL): 'FarField',
        (enums.Language.RU, enums.Model.PHONE_CALL): 'TelecomRus',
        (enums.Language.KZ, enums.Model.PHONE_CALL): 'TelecomKz',
        (enums.Language.EN, enums.Model.PHONE_CALL): 'TelecomEngUs',
        (enums.Language.ES, enums.Model.PHONE_CALL): 'TelecomEsp'
    }


    def recognize(self, config, audio):
        b64encoded_audio = base64.standard_b64encode(audio)
        audio_str = str(b64encoded_audio, 'ascii', 'ignore')

        recognize_api = RecognizeApi()
        audio_file = AudioFileDto(audio_str, config.get('encoding', enums.AudioEncoding.WAV).value)

        try:
            model = config[CONFIG_MODEL_KEY] \
                        if isinstance(config[CONFIG_MODEL_KEY], enums.Model) \
                        else enums.Model[config[CONFIG_MODEL_KEY]]
        except:
            raise ValueError(f"Model is not provided or does not exist. Available models: {' '.join([m.name for m in enums.Model])}")

        try:
            mapped_model = self.model_mapping[(config.get('language', enums.Language.RU), model)]
        except:
            raise ValueError('Provided language is not supported')

        recognition_request = RecognitionRequestDto(
            audio_file, mapped_model
        )
        response_type = config.get('response_type', enums.ResponseType.PLAIN_TEXT)
        if response_type == enums.ResponseType.PLAIN_TEXT:
            return recognize_api.recognize(self.session_id, recognition_request)
        elif response_type == enums.ResponseType.WORD_LIST:
            return recognize_api.recognize_words(self.session_id, recognition_request)
        elif response_type == enums.ResponseType.MULTICHANNEL:
            channel_count = config.get('audio_channel_count', 1)
            return recognize_api.recognize_advanced(
                self.session_id,
                AdvancedRecognitionRequestDto(
                    mapped_model, channels=[i for i in range(0, channel_count)], data=audio_str
                )
            )


class LongRunningRecognitionClient():
    pass


# coding: utf-8

"""
    TTS documentation

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.1

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from speechpro.cloud.speech.synthesis.rest.cloud_client.models.synthesize_text import SynthesizeText  # noqa: F401,E501


class SynthesizeRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'text': 'SynthesizeText',
        'voice_name': 'str',
        'audio': 'str'
    }

    attribute_map = {
        'text': 'text',
        'voice_name': 'voice_name',
        'audio': 'audio'
    }

    def __init__(self, text=None, voice_name=None, audio=None):  # noqa: E501
        """SynthesizeRequest - a model defined in Swagger"""  # noqa: E501

        self._text = None
        self._voice_name = None
        self._audio = None
        self.discriminator = None

        self.text = text
        self.voice_name = voice_name
        self.audio = audio

    @property
    def text(self):
        """Gets the text of this SynthesizeRequest.  # noqa: E501

        Text for synthesize to speech  # noqa: E501

        :return: The text of this SynthesizeRequest.  # noqa: E501
        :rtype: SynthesizeText
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this SynthesizeRequest.

        Text for synthesize to speech  # noqa: E501

        :param text: The text of this SynthesizeRequest.  # noqa: E501
        :type: SynthesizeText
        """
        if text is None:
            raise ValueError("Invalid value for `text`, must not be `None`")  # noqa: E501

        self._text = text

    @property
    def voice_name(self):
        """Gets the voice_name of this SynthesizeRequest.  # noqa: E501

        Name of name  # noqa: E501

        :return: The voice_name of this SynthesizeRequest.  # noqa: E501
        :rtype: str
        """
        return self._voice_name

    @voice_name.setter
    def voice_name(self, voice_name):
        """Sets the voice_name of this SynthesizeRequest.

        Name of name  # noqa: E501

        :param voice_name: The voice_name of this SynthesizeRequest.  # noqa: E501
        :type: str
        """
        if voice_name is None:
            raise ValueError("Invalid value for `voice_name`, must not be `None`")  # noqa: E501

        self._voice_name = voice_name

    @property
    def audio(self):
        """Gets the audio of this SynthesizeRequest.  # noqa: E501

        Format of response audio  # noqa: E501

        :return: The audio of this SynthesizeRequest.  # noqa: E501
        :rtype: str
        """
        return self._audio

    @audio.setter
    def audio(self, audio):
        """Sets the audio of this SynthesizeRequest.

        Format of response audio  # noqa: E501

        :param audio: The audio of this SynthesizeRequest.  # noqa: E501
        :type: str
        """
        if audio is None:
            raise ValueError("Invalid value for `audio`, must not be `None`")  # noqa: E501

        self._audio = audio

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SynthesizeRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from speechpro.cloud.speech.common.rest.cloud_client import SessionApi, AuthRequestDto


class SpeechproApiClientBase:
    def __init__(self, username, domain_id, password):
        self.username = username
        self.domain_id = domain_id
        self.password = password
        self._session_id = None


    @property
    def session_id(self):
        if not self._session_id:
            session_api = SessionApi()
            credentials = AuthRequestDto(self.username, self.domain_id, self.password)
            self._session_id = session_api.login(credentials).session_id
        return self._session_id


# coding: utf-8

"""
    ASR documentation

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class StartSessionRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'username': 'str',
        'password': 'str',
        'domain_id': 'int'
    }

    attribute_map = {
        'username': 'username',
        'password': 'password',
        'domain_id': 'domain_id'
    }

    def __init__(self, username=None, password=None, domain_id=None):  # noqa: E501
        """StartSessionRequest - a model defined in Swagger"""  # noqa: E501

        self._username = None
        self._password = None
        self._domain_id = None
        self.discriminator = None

        self.username = username
        self.password = password
        self.domain_id = domain_id

    @property
    def username(self):
        """Gets the username of this StartSessionRequest.  # noqa: E501

        User login  # noqa: E501

        :return: The username of this StartSessionRequest.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this StartSessionRequest.

        User login  # noqa: E501

        :param username: The username of this StartSessionRequest.  # noqa: E501
        :type: str
        """
        if username is None:
            raise ValueError("Invalid value for `username`, must not be `None`")  # noqa: E501

        self._username = username

    @property
    def password(self):
        """Gets the password of this StartSessionRequest.  # noqa: E501

        User password  # noqa: E501

        :return: The password of this StartSessionRequest.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this StartSessionRequest.

        User password  # noqa: E501

        :param password: The password of this StartSessionRequest.  # noqa: E501
        :type: str
        """
        if password is None:
            raise ValueError("Invalid value for `password`, must not be `None`")  # noqa: E501

        self._password = password

    @property
    def domain_id(self):
        """Gets the domain_id of this StartSessionRequest.  # noqa: E501

        User domain identifier  # noqa: E501

        :return: The domain_id of this StartSessionRequest.  # noqa: E501
        :rtype: int
        """
        return self._domain_id

    @domain_id.setter
    def domain_id(self, domain_id):
        """Sets the domain_id of this StartSessionRequest.

        User domain identifier  # noqa: E501

        :param domain_id: The domain_id of this StartSessionRequest.  # noqa: E501
        :type: int
        """
        if domain_id is None:
            raise ValueError("Invalid value for `domain_id`, must not be `None`")  # noqa: E501

        self._domain_id = domain_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StartSessionRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa
"""
    ASR documentation

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.1

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from speechpro.cloud.speech.recognition.rest.cloud_client.models.asr_advanced_result_dto import ASRAdvancedResultDto
from speechpro.cloud.speech.recognition.rest.cloud_client.models.asr_result_dto import ASRResultDto
from speechpro.cloud.speech.recognition.rest.cloud_client.models.advanced_recognition_request_dto import AdvancedRecognitionRequestDto
from speechpro.cloud.speech.recognition.rest.cloud_client.models.audio_file_dto import AudioFileDto
from speechpro.cloud.speech.recognition.rest.cloud_client.models.message_dto import MessageDto
from speechpro.cloud.speech.recognition.rest.cloud_client.models.package_dto import PackageDto
from speechpro.cloud.speech.recognition.rest.cloud_client.models.recognition_request_dto import RecognitionRequestDto
from speechpro.cloud.speech.recognition.rest.cloud_client.models.sessionless_recognition_request_dto import SessionlessRecognitionRequestDto
from speechpro.cloud.speech.recognition.rest.cloud_client.models.start_session_request import StartSessionRequest
from speechpro.cloud.speech.recognition.rest.cloud_client.models.status_dto import StatusDto
from speechpro.cloud.speech.recognition.rest.cloud_client.models.stream_request_dto import StreamRequestDto
from speechpro.cloud.speech.recognition.rest.cloud_client.models.stream_response_dto import StreamResponseDto
from speechpro.cloud.speech.recognition.rest.cloud_client.models.word_dto import WordDto
from speechpro.cloud.speech.recognition.rest.cloud_client.models.auth_response_dto import AuthResponseDto
from speechpro.cloud.speech.recognition.rest.cloud_client.models.auth_status_dto import AuthStatusDto



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
import speechpro.cloud.speech.synthesis.rest.cloud_client.api.session_api
import speechpro.cloud.speech.synthesis.rest.cloud_client.api.synthesize_api



import base64

from speechpro.cloud.speech.synthesis.rest.cloud_client import Synthesize, SynthesizeRequest, SynthesizeText
from speechpro.cloud.speech.synthesis import enums

class BatchSynthesisClient:
    voice_profile_mapping = {
        (enums.Voice.VLADIMIR, enums.PlaybackProfile.SPEAKER): 'Vladimir_n',
        (enums.Voice.VLADIMIR, enums.PlaybackProfile.PHONE_CALL): 'Vladimir_8000n',
        (enums.Voice.ANNA, enums.PlaybackProfile.SPEAKER): 'Anna_n',
        (enums.Voice.ANNA, enums.PlaybackProfile.PHONE_CALL): 'Anna_8000n',
        (enums.Voice.JULIA, enums.PlaybackProfile.SPEAKER): 'Julia_n',
        (enums.Voice.JULIA, enums.PlaybackProfile.PHONE_CALL): 'Julia_8000n',
    }


    def get_enum_value(self, value, enum_type):
        return value if isinstance(value, enum_type) else enum_type[value]


    def synthesize(self, voice, profile, text):
        try:
            voice = self.get_enum_value(voice, enums.Voice)
            profile = self.get_enum_value(profile, enums.PlaybackProfile)
            mapped_voice = self.voice_profile_mapping[(voice, profile)]
        except KeyError:
            raise ValueError('Incorrect combination of voice and playback profile')
        synthesize = Synthesize()
        text_request = SynthesizeText("text/plain", text)
        synthesize_request = SynthesizeRequest(text_request, mapped_voice, "audio/wav")
        audio_data = synthesize.synthesize(self.session_id, synthesize_request)
        sound = base64.decodebytes(bytes(audio_data.data, 'utf-8'))

        return sound


# coding: utf-8

"""
    ASR documentation

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class AdvancedRecognitionRequestDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'package_id': 'str',
        'channels': 'list[int]',
        'data': 'str'
    }

    attribute_map = {
        'package_id': 'package_id',
        'channels': 'channels',
        'data': 'data'
    }

    def __init__(self, package_id=None, channels=None, data=None):  # noqa: E501
        """AdvancedRecognitionRequestDto - a model defined in Swagger"""  # noqa: E501

        self._package_id = None
        self._channels = None
        self._data = None
        self.discriminator = None

        if package_id is not None:
            self.package_id = package_id
        if channels is not None:
            self.channels = channels
        self.data = data

    @property
    def package_id(self):
        """Gets the package_id of this AdvancedRecognitionRequestDto.  # noqa: E501

        Recognize with package  # noqa: E501

        :return: The package_id of this AdvancedRecognitionRequestDto.  # noqa: E501
        :rtype: str
        """
        return self._package_id

    @package_id.setter
    def package_id(self, package_id):
        """Sets the package_id of this AdvancedRecognitionRequestDto.

        Recognize with package  # noqa: E501

        :param package_id: The package_id of this AdvancedRecognitionRequestDto.  # noqa: E501
        :type: str
        """

        self._package_id = package_id

    @property
    def channels(self):
        """Gets the channels of this AdvancedRecognitionRequestDto.  # noqa: E501

        Specific channels to process  # noqa: E501

        :return: The channels of this AdvancedRecognitionRequestDto.  # noqa: E501
        :rtype: list[int]
        """
        return self._channels

    @channels.setter
    def channels(self, channels):
        """Sets the channels of this AdvancedRecognitionRequestDto.

        Specific channels to process  # noqa: E501

        :param channels: The channels of this AdvancedRecognitionRequestDto.  # noqa: E501
        :type: list[int]
        """

        self._channels = channels

    @property
    def data(self):
        """Gets the data of this AdvancedRecognitionRequestDto.  # noqa: E501

        Binary audio file as Base64 string  # noqa: E501

        :return: The data of this AdvancedRecognitionRequestDto.  # noqa: E501
        :rtype: str
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this AdvancedRecognitionRequestDto.

        Binary audio file as Base64 string  # noqa: E501

        :param data: The data of this AdvancedRecognitionRequestDto.  # noqa: E501
        :type: str
        """
        if data is None:
            raise ValueError("Invalid value for `data`, must not be `None`")  # noqa: E501

        self._data = data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AdvancedRecognitionRequestDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ASR documentation

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PackageDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'package_id': 'str',
        'name': 'str',
        'language': 'str',
        'sample_rate': 'int',
        'loaded': 'bool'
    }

    attribute_map = {
        'package_id': 'package_id',
        'name': 'name',
        'language': 'language',
        'sample_rate': 'sample_rate',
        'loaded': 'loaded'
    }

    def __init__(self, package_id=None, name=None, language=None, sample_rate=None, loaded=None):  # noqa: E501
        """PackageDto - a model defined in Swagger"""  # noqa: E501

        self._package_id = None
        self._name = None
        self._language = None
        self._sample_rate = None
        self._loaded = None
        self.discriminator = None

        self.package_id = package_id
        self.name = name
        self.language = language
        self.sample_rate = sample_rate
        self.loaded = loaded

    @property
    def package_id(self):
        """Gets the package_id of this PackageDto.  # noqa: E501

        Package ID  # noqa: E501

        :return: The package_id of this PackageDto.  # noqa: E501
        :rtype: str
        """
        return self._package_id

    @package_id.setter
    def package_id(self, package_id):
        """Sets the package_id of this PackageDto.

        Package ID  # noqa: E501

        :param package_id: The package_id of this PackageDto.  # noqa: E501
        :type: str
        """
        if package_id is None:
            raise ValueError("Invalid value for `package_id`, must not be `None`")  # noqa: E501

        self._package_id = package_id

    @property
    def name(self):
        """Gets the name of this PackageDto.  # noqa: E501

        Package name  # noqa: E501

        :return: The name of this PackageDto.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PackageDto.

        Package name  # noqa: E501

        :param name: The name of this PackageDto.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def language(self):
        """Gets the language of this PackageDto.  # noqa: E501

        Package language  # noqa: E501

        :return: The language of this PackageDto.  # noqa: E501
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this PackageDto.

        Package language  # noqa: E501

        :param language: The language of this PackageDto.  # noqa: E501
        :type: str
        """
        if language is None:
            raise ValueError("Invalid value for `language`, must not be `None`")  # noqa: E501

        self._language = language

    @property
    def sample_rate(self):
        """Gets the sample_rate of this PackageDto.  # noqa: E501

        Required sample rate of data  # noqa: E501

        :return: The sample_rate of this PackageDto.  # noqa: E501
        :rtype: int
        """
        return self._sample_rate

    @sample_rate.setter
    def sample_rate(self, sample_rate):
        """Sets the sample_rate of this PackageDto.

        Required sample rate of data  # noqa: E501

        :param sample_rate: The sample_rate of this PackageDto.  # noqa: E501
        :type: int
        """
        if sample_rate is None:
            raise ValueError("Invalid value for `sample_rate`, must not be `None`")  # noqa: E501

        self._sample_rate = sample_rate

    @property
    def loaded(self):
        """Gets the loaded of this PackageDto.  # noqa: E501

        Is package loaded to the cache  # noqa: E501

        :return: The loaded of this PackageDto.  # noqa: E501
        :rtype: bool
        """
        return self._loaded

    @loaded.setter
    def loaded(self, loaded):
        """Sets the loaded of this PackageDto.

        Is package loaded to the cache  # noqa: E501

        :param loaded: The loaded of this PackageDto.  # noqa: E501
        :type: bool
        """
        if loaded is None:
            raise ValueError("Invalid value for `loaded`, must not be `None`")  # noqa: E501

        self._loaded = loaded

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PackageDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from speechpro.cloud.speech.synthesis import rest
from speechpro.cloud.speech import common
from speechpro.cloud.speech.synthesis import enums

class SynthesisClient(common.SpeechproApiClientBase, rest.BatchSynthesisClient):
    pass


__all__ = ('SynthesisClient', 'enums')


# coding: utf-8

# flake8: noqa

"""
    TTS documentation

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.1

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from speechpro.cloud.speech.common.rest.cloud_client.api.session_api import SessionApi

# import ApiClient
from speechpro.cloud.speech.common.rest.cloud_client.cloud_api_client import CloudApiClient
from speechpro.cloud.speech.common.rest.cloud_client.configuration import Configuration
# import models into sdk package
from speechpro.cloud.speech.common.rest.cloud_client.models.auth_response_dto import AuthResponseDto
from speechpro.cloud.speech.common.rest.cloud_client.models.auth_request_dto import AuthRequestDto


# coding: utf-8

"""
    ASR documentation

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.1

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from speechpro.cloud.speech.recognition.rest.cloud_client.cloud_api_client import CloudApiClient


class RecognizeApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = CloudApiClient()
        self.api_client = api_client

    def close(self, x_session_id, x_transaction_id, **kwargs):  # noqa: E501
        """Close transaction  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.close(x_session_id, x_transaction_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str x_session_id: Session identifier (required)
        :param str x_transaction_id: Session identifier (required)
        :return: ASRResultDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.close_with_http_info(x_session_id, x_transaction_id, **kwargs)  # noqa: E501
        else:
            (data) = self.close_with_http_info(x_session_id, x_transaction_id, **kwargs)  # noqa: E501
            return data

    def close_with_http_info(self, x_session_id, x_transaction_id, **kwargs):  # noqa: E501
        """Close transaction  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.close_with_http_info(x_session_id, x_transaction_id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str x_session_id: Session identifier (required)
        :param str x_transaction_id: Session identifier (required)
        :return: ASRResultDto
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_session_id', 'x_transaction_id']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method close" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'x_session_id' is set
        if ('x_session_id' not in params or
                params['x_session_id'] is None):
            raise ValueError("Missing the required parameter `x_session_id` when calling `close`")  # noqa: E501
        # verify the required parameter 'x_transaction_id' is set
        if ('x_transaction_id' not in params or
                params['x_transaction_id'] is None):
            raise ValueError("Missing the required parameter `x_transaction_id` when calling `close`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_session_id' in params:
            header_params['X-Session-ID'] = params['x_session_id']  # noqa: E501
        if 'x_transaction_id' in params:
            header_params['X-Transaction-Id'] = params['x_transaction_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=UTF-8'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/vkasr/rest/v1/recognize/stream', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ASRResultDto',  # noqa: E501
            auth_settings=auth_settings,
            async_=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def recognize(self, x_session_id, body, **kwargs):  # noqa: E501
        """Get speech recognition result  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.recognize(x_session_id, body, async=True)
        >>> result = thread.get()

        :param async bool
        :param str x_session_id: Session identifier (required)
        :param RecognitionRequestDto body: Recognition request with audio file, mime type and package ID (required)
        :param str x_request_id: Request identifier
        :return: ASRResultDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.recognize_with_http_info(x_session_id, body, **kwargs)  # noqa: E501
        else:
            (data) = self.recognize_with_http_info(x_session_id, body, **kwargs)  # noqa: E501
            return data

    def recognize_with_http_info(self, x_session_id, body, **kwargs):  # noqa: E501
        """Get speech recognition result  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.recognize_with_http_info(x_session_id, body, async=True)
        >>> result = thread.get()

        :param async bool
        :param str x_session_id: Session identifier (required)
        :param RecognitionRequestDto body: Recognition request with audio file, mime type and package ID (required)
        :param str x_request_id: Request identifier
        :return: ASRResultDto
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_session_id', 'body', 'x_request_id']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method recognize" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'x_session_id' is set
        if ('x_session_id' not in params or
                params['x_session_id'] is None):
            raise ValueError("Missing the required parameter `x_session_id` when calling `recognize`")  # noqa: E501
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `recognize`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_session_id' in params:
            header_params['X-Session-ID'] = params['x_session_id']  # noqa: E501
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=UTF-8'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/vkasr/rest/v1/recognize', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ASRResultDto',  # noqa: E501
            auth_settings=auth_settings,
            async_=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def recognize_advanced(self, x_session_id, body, **kwargs):  # noqa: E501
        """Recognize speech with advanced options  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.recognize_advanced(x_session_id, body, async=True)
        >>> result = thread.get()

        :param async bool
        :param str x_session_id: Session identifier (required)
        :param AdvancedRecognitionRequestDto body: Recognition request with audio file, mime type and package ID (required)
        :param str x_request_id: Request identifier
        :return: list[ASRAdvancedResultDto]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.recognize_advanced_with_http_info(x_session_id, body, **kwargs)  # noqa: E501
        else:
            (data) = self.recognize_advanced_with_http_info(x_session_id, body, **kwargs)  # noqa: E501
            return data

    def recognize_advanced_with_http_info(self, x_session_id, body, **kwargs):  # noqa: E501
        """Recognize speech with advanced options  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.recognize_advanced_with_http_info(x_session_id, body, async=True)
        >>> result = thread.get()

        :param async bool
        :param str x_session_id: Session identifier (required)
        :param AdvancedRecognitionRequestDto body: Recognition request with audio file, mime type and package ID (required)
        :param str x_request_id: Request identifier
        :return: list[ASRAdvancedResultDto]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_session_id', 'body', 'x_request_id']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method recognize_advanced" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'x_session_id' is set
        if ('x_session_id' not in params or
                params['x_session_id'] is None):
            raise ValueError("Missing the required parameter `x_session_id` when calling `recognize_advanced`")  # noqa: E501
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `recognize_advanced`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_session_id' in params:
            header_params['X-Session-ID'] = params['x_session_id']  # noqa: E501
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=UTF-8'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/vkasr/rest/v1/recognize/advanced', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ASRAdvancedResultDto]',  # noqa: E501
            auth_settings=auth_settings,
            async_=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def recognize_sessionless(self, body, **kwargs):  # noqa: E501
        """Get speech recognition result  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.recognize_sessionless(body, async=True)
        >>> result = thread.get()

        :param async bool
        :param SessionlessRecognitionRequestDto body: Request with user login data and recognition request (required)
        :param str x_request_id: Request identifier
        :return: ASRResultDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.recognize_sessionless_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.recognize_sessionless_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def recognize_sessionless_with_http_info(self, body, **kwargs):  # noqa: E501
        """Get speech recognition result  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.recognize_sessionless_with_http_info(body, async=True)
        >>> result = thread.get()

        :param async bool
        :param SessionlessRecognitionRequestDto body: Request with user login data and recognition request (required)
        :param str x_request_id: Request identifier
        :return: ASRResultDto
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'x_request_id']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method recognize_sessionless" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `recognize_sessionless`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=UTF-8'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/vkasr/rest/v1/recognize/sessionless', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ASRResultDto',  # noqa: E501
            auth_settings=auth_settings,
            async_=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def recognize_words(self, x_session_id, body, **kwargs):  # noqa: E501
        """Recognize speech and return word list  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.recognize_words(x_session_id, body, async=True)
        >>> result = thread.get()

        :param async bool
        :param str x_session_id: Session identifier (required)
        :param RecognitionRequestDto body: Recognition request with audio file, mime type and package ID (required)
        :param str x_request_id: Request identifier
        :return: list[WordDto]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.recognize_words_with_http_info(x_session_id, body, **kwargs)  # noqa: E501
        else:
            (data) = self.recognize_words_with_http_info(x_session_id, body, **kwargs)  # noqa: E501
            return data

    def recognize_words_with_http_info(self, x_session_id, body, **kwargs):  # noqa: E501
        """Recognize speech and return word list  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.recognize_words_with_http_info(x_session_id, body, async=True)
        >>> result = thread.get()

        :param async bool
        :param str x_session_id: Session identifier (required)
        :param RecognitionRequestDto body: Recognition request with audio file, mime type and package ID (required)
        :param str x_request_id: Request identifier
        :return: list[WordDto]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_session_id', 'body', 'x_request_id']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method recognize_words" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'x_session_id' is set
        if ('x_session_id' not in params or
                params['x_session_id'] is None):
            raise ValueError("Missing the required parameter `x_session_id` when calling `recognize_words`")  # noqa: E501
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `recognize_words`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_session_id' in params:
            header_params['X-Session-ID'] = params['x_session_id']  # noqa: E501
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=UTF-8'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/vkasr/rest/v1/recognize/words', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[WordDto]',  # noqa: E501
            auth_settings=auth_settings,
            async_=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def recognize_words_sessionless(self, body, **kwargs):  # noqa: E501
        """Recognize speech without session and return word list  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.recognize_words_sessionless(body, async=True)
        >>> result = thread.get()

        :param async bool
        :param SessionlessRecognitionRequestDto body: Request with user login data and recognition request (required)
        :param str x_request_id: Request identifier
        :return: list[WordDto]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.recognize_words_sessionless_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.recognize_words_sessionless_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def recognize_words_sessionless_with_http_info(self, body, **kwargs):  # noqa: E501
        """Recognize speech without session and return word list  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.recognize_words_sessionless_with_http_info(body, async=True)
        >>> result = thread.get()

        :param async bool
        :param SessionlessRecognitionRequestDto body: Request with user login data and recognition request (required)
        :param str x_request_id: Request identifier
        :return: list[WordDto]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'x_request_id']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method recognize_words_sessionless" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `recognize_words_sessionless`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=UTF-8'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/vkasr/rest/v1/recognize/sessionless/words', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[WordDto]',  # noqa: E501
            auth_settings=auth_settings,
            async_=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def start(self, x_session_id, body, **kwargs):  # noqa: E501
        """Start recognition stream  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.start(x_session_id, body, async=True)
        >>> result = thread.get()

        :param async bool
        :param str x_session_id: Session identifier (required)
        :param StreamRequestDto body: Transaction parameters (required)
        :param str x_request_id: Request identifier
        :return: StreamResponseDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.start_with_http_info(x_session_id, body, **kwargs)  # noqa: E501
        else:
            (data) = self.start_with_http_info(x_session_id, body, **kwargs)  # noqa: E501
            return data

    def start_with_http_info(self, x_session_id, body, **kwargs):  # noqa: E501
        """Start recognition stream  # noqa: E501

          # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.start_with_http_info(x_session_id, body, async=True)
        >>> result = thread.get()

        :param async bool
        :param str x_session_id: Session identifier (required)
        :param StreamRequestDto body: Transaction parameters (required)
        :param str x_request_id: Request identifier
        :return: StreamResponseDto
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_session_id', 'body', 'x_request_id']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method start" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'x_session_id' is set
        if ('x_session_id' not in params or
                params['x_session_id'] is None):
            raise ValueError("Missing the required parameter `x_session_id` when calling `start`")  # noqa: E501
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `start`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_session_id' in params:
            header_params['X-Session-ID'] = params['x_session_id']  # noqa: E501
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=UTF-8'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json;charset=UTF-8'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/vkasr/rest/v1/recognize/stream', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='StreamResponseDto',  # noqa: E501
            auth_settings=auth_settings,
            async_=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



import enum


class AudioEncoding(enum.Enum):
    WAV = 'audio/wav'
    OGG_OPUS = 'audio/ogg'


class Model(enum.IntEnum):
    GENERAL = 1
    PHONE_CALL = 2


class Language(enum.IntEnum):
    RU = 1
    EN = 2
    ES = 3
    KZ = 4


class ResponseType(enum.Enum):
    PLAIN_TEXT = 'plaintext'
    WORD_LIST = 'wordlist'
    MULTICHANNEL = 'multichannel'


#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = [
    'Click>=7.0',
    'certifi>=14.05.14',
    'six>=1.10',
    'python_dateutil>=2.5.3',
    'setuptools>=21.0.0',
    'urllib3>=1.15.1'
]

setup_requirements = [ ]

test_requirements = [ ]

setup(
    author="Dmitry Kozhedubov",
    author_email='hiisi13@gmail.com',
    python_requires='>=3.5',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    description="Python клиент для API распознавания и синтеза речи Облака ЦРТ",
    entry_points={
        'console_scripts': [
            'speechpro=speechpro.cli:cli',
        ],
    },
    install_requires=requirements,
    license="MIT license",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='speechpro',
    name='speechpro-cloud-python',
    packages=find_packages(include=['speechpro', 'speechpro.*']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/speechpro/cloud-python',
    version='0.1.5',
    zip_safe=False,
)



# coding: utf-8

# flake8: noqa

"""
    TTS documentation

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.1

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from speechpro.cloud.speech.synthesis.rest.cloud_client.api.synthesize_api import Synthesize
from speechpro.cloud.speech.synthesis.rest.cloud_client.api.session_api import SessionApi

# import ApiClient
from speechpro.cloud.speech.synthesis.rest.cloud_client.cloud_api_client import CloudApiClient
from speechpro.cloud.speech.synthesis.rest.cloud_client.configuration import Configuration
# import models into sdk package
from speechpro.cloud.speech.synthesis.rest.cloud_client.models.close_transaction_response import CloseTransactionResponse
from speechpro.cloud.speech.synthesis.rest.cloud_client.models.credentials import Credentials
from speechpro.cloud.speech.synthesis.rest.cloud_client.models.exception_model import ExceptionModel
from speechpro.cloud.speech.synthesis.rest.cloud_client.models.synthesize_language import SynthesizeLanguage
from speechpro.cloud.speech.synthesis.rest.cloud_client.models.synthesize_request import SynthesizeRequest
from speechpro.cloud.speech.synthesis.rest.cloud_client.models.synthesize_response import SynthesizeResponse
from speechpro.cloud.speech.synthesis.rest.cloud_client.models.synthesize_sessionless_request import SynthesizeSessionlessRequest
from speechpro.cloud.speech.synthesis.rest.cloud_client.models.synthesize_text import SynthesizeText
from speechpro.cloud.speech.synthesis.rest.cloud_client.models.synthesize_voice_type import SynthesizeVoiceType
from speechpro.cloud.speech.synthesis.rest.cloud_client.models.web_socket_server_configuration_response import WebSocketServerConfigurationResponse
from speechpro.cloud.speech.synthesis.rest.cloud_client.models.web_socket_synthesize_request import WebSocketSynthesizeRequest
from speechpro.cloud.speech.synthesis.rest.cloud_client.models.web_socket_text_param import WebSocketTextParam
from speechpro.cloud.speech.synthesis.rest.cloud_client.models.auth_response_dto import AuthResponseDto


from speechpro.cloud.speech.recognition import rest
from speechpro.cloud.speech import common


class RecognitionClient(common.SpeechproApiClientBase, rest.ShortAudioRecognitionClient, rest.LongRunningRecognitionClient):
    pass


__all__ = ('RecognitionClient')


import os
import sys

import click

from speechpro.cloud.speech import recognition
from speechpro.cloud.speech import synthesis


recognitionClient = recognition.RecognitionClient(
    os.environ['SPEECHPRO_USERNAME'],
    os.environ['SPEECHPRO_DOMAIN_ID'],
    os.environ['SPEECHPRO_PASSWORD']
)

synthesisClient = synthesis.SynthesisClient(
    os.environ['SPEECHPRO_USERNAME'],
    os.environ['SPEECHPRO_DOMAIN_ID'],
    os.environ['SPEECHPRO_PASSWORD']
)


def recognize(language, model, response_type, filename, audio_channel_count=1):
    with open(filename, "rb") as f:
        content = f.read()

    config = {
        'language': language,
        'model': model,
        'encoding': recognition.enums.AudioEncoding.WAV,
        'response_type': response_type,
        'audio_channel_count': audio_channel_count
    }
    return recognitionClient.recognize(config, content)


@click.group()
def cli():
    pass

@cli.command()
@click.option('--language', default=recognition.enums.Language.RU)
@click.option('--model', default=recognition.enums.Model.GENERAL)
@click.option('--filename', type=str,)
def recognize_plain_text(language, model, filename):
    result = recognize(language, model, recognition.enums.ResponseType.PLAIN_TEXT, filename)
    print(result.text)
    return 0


@cli.command()
@click.option('--language', default=recognition.enums.Language.RU)
@click.option('--model', default=recognition.enums.Model.GENERAL)
@click.option('--filename', type=str,)
def recognize_word_list(language, model, filename):
    result = recognize(language, model, recognition.enums.ResponseType.WORD_LIST, filename)
    for w in result:
        print(w.word)
    return 0


@cli.command()
@click.option('--language', default=recognition.enums.Language.RU)
@click.option('--model', default=recognition.enums.Model.GENERAL)
@click.option('--filename', type=str,)
@click.option('--audio_channel_count', type=int,)
def recognize_multichannel(language, model, filename, audio_channel_count):
    result = recognize(language, model, recognition.enums.ResponseType.MULTICHANNEL, filename, audio_channel_count)
    for ch in result:
        print(f'Channel {ch.channel_id}')
        for w in ch.result:
            print(w.word)
        print('\n')
    return 0


@cli.command()
@click.option('--voice', default=synthesis.enums.Voice.JULIA)
@click.option('--profile', default=synthesis.enums.PlaybackProfile.SPEAKER)
@click.option('--output', type=str)
@click.option('--input', type=str)
def synthesize(voice, profile, output, input):
    try:
        with open(input) as f:
            text = f.read()
    except:
        text = input
    audio = synthesisClient.synthesize(voice, profile, text)

    with open(output, 'wb') as outputfile:
        outputfile.write(audio)



if __name__ == "__main__":
    sys.exit(cli())  # pragma: no cover